"use strict";

var _postcss = _interopRequireDefault(require("postcss"));

var _fs = _interopRequireDefault(require("fs"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = _postcss.default.plugin('autoprefixer', prefixConfig => {
  const filePath = prefixConfig && prefixConfig.defaultPrefixesPath ? prefixConfig.defaultPrefixesPath : './defaultPrefixes.json';
  const prefixes = JSON.parse(_fs.default.readFileSync(filePath, 'utf-8'));
  const prefixVals = Object.keys(prefixes).filter(key => prefixes[key].key);
  const prefixValObj = {};
  prefixVals.forEach(val => {
    prefixValObj[prefixes[val].value] = prefixes[val];
  });
  return root => {
    root.walkAtRules(rule => {
      const previous = rule.parent.nodes[rule.parent.nodes.indexOf(rule) - 1];

      if (previous && previous.type === 'comment' && previous.text === 'prefix:ignore') {
        return;
      }

      if (rule.name === 'keyframes' && !prefixConfig.exclude.includes('@keyframes') && prefixConfig.include && (Object.keys(prefixConfig.include).length === 0 || Object.keys(prefixConfig.include).includes('@keyframes'))) {
        const newPrefixes = [];
        const replacements = prefixConfig.replacements && prefixConfig.replacements['@keyframes'] ? prefixConfig.replacements['@keyframes'] : {}; // if (!prefixes['@keyframes'] && !replacements) {
        //   return;
        // }

        const mozRule = rule.clone();

        if (mozRule.name && prefixConfig.browsers && prefixConfig.browsers.mozilla) {
          // custom value need to change
          if (prefixConfig.include['@keyframes'] && !prefixConfig.include['@keyframes'].mozilla && !prefixes['@keyframes'].mozilla) {
            return;
          }

          mozRule.name = replacements && replacements.mozilla ? replacements.mozilla : prefixes['@keyframes'].mozilla;

          if (mozRule.name !== undefined) {
            newPrefixes.push(mozRule);
          }
        }

        const chromeRule = rule.clone(); // custom value need to change

        if (chromeRule.name && prefixConfig.browsers && prefixConfig.browsers.chrome) {
          if (prefixConfig.include['@keyframes'] && !prefixConfig.include['@keyframes'].chrome && !prefixes['@keyframes'].chrome) {
            return;
          }

          chromeRule.name = replacements && replacements.chrome ? replacements.chrome : prefixes['@keyframes'].chrome;

          if (chromeRule.name !== undefined) {
            newPrefixes.push(chromeRule);
          }
        }

        const operaRule = rule.clone(); // custom value need to change

        if (operaRule.name && prefixConfig.browsers && prefixConfig.browsers.opera) {
          if (prefixConfig.include['@keyframes'] && !prefixConfig.include['@keyframes'].opera && !prefixes['@keyframes'].opera) {
            return;
          }

          operaRule.name = replacements && replacements.opera ? replacements.opera : prefixes['@keyframes'].opera;

          if (operaRule.name !== undefined) {
            newPrefixes.push(operaRule);
          }
        }

        const ieRule = rule.clone(); // custom value need to change

        if (ieRule.name && prefixConfig.browsers && prefixConfig.browsers.ie) {
          if (prefixConfig.include['@keyframes'] && !prefixConfig.include['@keyframes'].ie && !prefixes['@keyframes'].ie) {
            return;
          }

          ieRule.name = replacements && replacements.ie ? replacements.ie : prefixes['@keyframes'].ie;

          if (ieRule.name !== undefined) {
            newPrefixes.push(ieRule);
          }
        }

        rule.parent.insertAfter(rule, newPrefixes); // console.log(`${rule.name} : ${rule.params}`);

        return;
      }
    });
    root.walkRules(rule => {
      rule.walkDecls(decl => {
        const previous = decl.parent.nodes[decl.parent.nodes.indexOf(decl) - 1];

        if (previous && previous.type === 'comment' && previous.text === 'prefix:ignore') {
          return;
        }

        if (Object.keys(prefixes).includes(decl.prop) && !prefixConfig.exclude.includes(decl.prop) && prefixConfig.include && (Object.keys(prefixConfig.include).length === 0 || Object.keys(prefixConfig.include).includes(decl.prop))) {
          const newPrefixes = [];
          const replacements = prefixConfig.replacements && prefixConfig.replacements[decl.prop] ? prefixConfig.replacements[decl.prop] : {}; // if (!prefixes[decl.prop] && !replacements) {
          //   return;
          // }

          const mozDecl = decl.clone(); // custom value need to change

          if (mozDecl.prop && prefixConfig.browsers && prefixConfig.browsers.mozilla) {
            if (prefixConfig.include[decl.prop] && !prefixConfig.include[decl.prop].mozilla && !prefixes[decl.prop].mozilla) {
              return;
            }

            mozDecl.prop = replacements && replacements.mozilla ? replacements.mozilla : prefixes[decl.prop].mozilla;

            if (mozDecl.prop !== undefined) {
              newPrefixes.push(mozDecl);
            }
          }

          const chromeDecl = decl.clone(); // custom value need to change

          if (chromeDecl.prop && prefixConfig.browsers && prefixConfig.browsers.chrome) {
            if (prefixConfig.include[decl.prop] && !prefixConfig.include[decl.prop].chrome && !prefixes[decl.prop].chrome) {
              return;
            }

            chromeDecl.prop = replacements && replacements.chrome ? replacements.chrome : prefixes[decl.prop].chrome;

            if (chromeDecl.prop !== undefined) {
              newPrefixes.push(chromeDecl);
            }
          }

          const operaDecl = decl.clone(); // custom value need to change

          if (operaDecl.prop && prefixConfig.browsers && prefixConfig.browsers.opera) {
            if (prefixConfig.include[decl.prop] && !prefixConfig.include[decl.prop].opera && !prefixes[decl.prop].opera) {
              return;
            }

            operaDecl.prop = replacements && replacements.opera ? replacements.opera : prefixes[decl.prop].opera;

            if (operaDecl.prop !== undefined) {
              newPrefixes.push(operaDecl);
            }
          }

          const ieDecl = decl.clone(); // custom value need to change

          if (ieDecl.prop && prefixConfig.browsers && prefixConfig.browsers.ie) {
            if (prefixConfig.include[decl.prop] && !prefixConfig.include[decl.prop].ie && !prefixes[decl.prop].ie) {
              return;
            }

            ieDecl.prop = replacements && replacements.ie ? replacements.ie : prefixes[decl.prop].ie;

            if (ieDecl.prop !== undefined) {
              newPrefixes.push(ieDecl);
            }
          }

          decl.parent.insertAfter(decl, newPrefixes); // console.log(`${decl.prop} : ${decl.value}`);
        }
      });
    });
  };
});